#########################################################################
#
# Copyright (C) 2014 StarterKit Development Team
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
#########################################################################

import os
# __version__ = (1, 2, 0, 'alpha', 6)
__version__ = (1, 2, 16, 'final', 0)

class UnregisteredSKException(Exception):
    pass

def get_version():
    import geonode.version
    return geonode.version.get_version(__version__)
